## 0.0.31

This new version includes enhancements to the directory tree functionality and some minor changes.

### New Features

- Added functionality to display the directory tree (e8248d) (Eric Ma)
- Ensured that the directory tree context is passed into the prompt (df93e5) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.

### Other Changes

- More scratch work done (96b60b) (Eric Ma)
- Version bumped from 0.0.30 to 0.0.31 (36e55b) (Eric Ma)
